use std::{thread, time};

use crate::action::update_ports_tree;

mod action;
mod db;

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let db_path = std::env::args()
        .nth(1)
        .ok_or("Pass path to sqlite DB in first parameter.")?;
    let mut db_conn: db::DbHandle = db::DbHandle::new(db_path)?;

    loop {
        for pending_global_action in db_conn.get_pending_global_actions()? {
            match pending_global_action.name.as_str() {
                ACTION_UPDATE_PORTS_TREE => {
                    update_ports_tree(&mut db_conn)?;
                }
                _ => {
                    panic!("Unknown global action: {}", pending_global_action.name);
                }
            };
        }

        let pending_local_actions = db_conn.get_pending_local_actions()?;

        let time_until_next_action = db_conn.get_time_until_next_action()?;
        let sleep_duration = std::cmp::min(
            time::Duration::from_secs(60),
            std::cmp::max(time_until_next_action, time::Duration::from_secs(300)),
        );
        println!("Sleeping for {} seconds.", sleep_duration.as_secs());
        thread::sleep(sleep_duration);
    }
}
